@@ -5,6 +5,7 @@ Created on Fri Jul 30 13:22:34 2021
 @author: chang.sun
 """
 
+import sc_backtest.ta_personal as ta2
 import sc_backtest.technical_analysis as ta
-from .simpletest import simpletest, get_report
-from .backtest import *
+from .simpletest import simpletest
+import sc_backtest.backtest as bt
