@@ -25,18 +25,13 @@ def _preprocessing(x, y):
 
 
 def _get_report(delta, ret):
-    """
-    :param delta: pd.Series
-    :param ret: pd.Series
-    :return: report: pd.DataFrame
-    """
     if len(delta) != len(ret):
         print(F'mismatched length of indicator, pnl, len(indicator) == {len(delta)} len(ret) == {len(ret)}')
         return
 
     pnl = delta * ret
 
-    day_pnl = pnl.resample('D').sum()
+    day_pnl = pnl.groupby(by=pnl.index.to_series().apply(lambda x: x.date())).sum()
 
     # year PnL
     pnl_y = round(day_pnl.mean() * 251, 2)
