@@ -13,51 +13,16 @@ from .private_func import _preprocessing
 from .private_func import _get_report
 
 
-def get_report(delta, ret):
-    """
-    delta: pd.Series with DatatimeIndex
-    ret: pd.Series with DatatimeIndex
-    report: pd.DataFrame
-    """
-    if len(delta) != len(ret):
-        print(F'mismatched length of indicator, pnl, len(indicator) == {len(delta)} len(ret) == {len(ret)}')
-        return
-
-    if not (isinstance(delta, pd.Series)) or not (isinstance(ret, pd.Series)):
-        print('indicator and pnl must be pd.Series')
-        return
-
-    if not (isinstance(delta.index, pd.core.indexes.datetimes.DatetimeIndex)) \
-            or not (isinstance(ret.index, pd.core.indexes.datetimes.DatetimeIndex)):
-        print('index of indicator and pnl must be pd.core.indexes.datetimes.DatetimeIndex')
-        return
-
-    indicator = copy(delta)
-    ret = copy(ret)
-
-    valid_ind = np.isfinite(indicator)
-    indicator = indicator[valid_ind]
-    ret = ret[valid_ind]
-
-    report_all = _get_report(indicator, ret).rename('All').to_frame().T
-    report_sub = indicator.resample('Y').apply(lambda x: _get_report(x, ret.reindex(x.index))).unstack()
-    report_sub.index = report_sub.index.to_series().apply(lambda x: x.year)
-
-    return pd.concat([report_all, report_sub])
-
-
 class simpletest():
     """
     Index Future Backtest Module
     """
 
-    def __init__(self, is_day=True, freq=1):
+    def __init__(self, is_day=True):
         """
         is_day: bool
-        freq: int: if is_day is False, then one must set the freq for the minute data
         """
         self.is_day = is_day
-        self.freq = freq
 
     def simple_pnl(self, x, y,
                    ax=None, plot=True, data_return=False, sign=True, med=True):
@@ -88,7 +53,7 @@ class simpletest():
             if self.is_day:
                 day_pnl1 = pnl1
             else:
-                day_pnl1 = sum_pnl1[self.freq - 1::self.freq].diff()
+                day_pnl1 = pnl1.groupby(by=pnl1.index.to_series().apply(lambda m: m.date())).sum()
 
             # PoT
             pot1 = pnl1.sum() / (indicator1.diff().abs().sum()) * 1e4
@@ -123,7 +88,7 @@ class simpletest():
             if self.is_day:
                 day_pnl2 = pnl2
             else:
-                day_pnl2 = sum_pnl2[self.freq - 1::self.freq].diff()
+                day_pnl2 = pnl2.groupby(by=pnl2.index.to_series().apply(lambda m: m.date())).sum()
 
             # PoT
             pot2 = pnl2.sum() / (indicator2.diff().abs().sum()) * 1e4
@@ -197,7 +162,7 @@ class simpletest():
         if self.is_day:
             day_pnl = pnl
         else:
-            day_pnl = sum_pnl[self.freq - 1::self.freq].diff()
+            day_pnl = pnl.groupby(by=pnl.index.to_series().apply(lambda m: m.date())).sum()
 
         # PoT
         pot = pnl.sum() / (indicator.diff().abs().sum()) * 1e4
